@@ -7,6 +7,7 @@
     asm_sub_register,
     bad_asm_style,
     bindings_with_variant_name,
+    break_with_label_and_loop,
     cenum_impl_drop_cast,
     clashing_extern_declarations,
     coherence_leak_check,
@@ -17,11 +18,15 @@
     const_item_mutation,
     dead_code,
     deprecated,
+    deprecated_cfg_attr_crate_type_name,
     deprecated_in_future,
+    deref_into_dyn_supertrait,
     deref_nullptr,
     drop_bounds,
+    duplicate_macro_attributes,
     dyn_drop,
     ellipsis_inclusive_range_patterns,
+    enum_intrinsics_non_enums,
     explicit_outlives_requirements,
     exported_private_dependencies,
     forbidden_lint_groups,
@@ -35,6 +40,7 @@
     indirect_structural_match,
     ineffective_unstable_trait_impl,
     inline_no_sanitize,
+    invalid_atomic_ordering,
     invalid_doc_attributes,
     invalid_type_param_default,
     invalid_value,
@@ -52,6 +58,7 @@
     mixed_script_confusables,
     mutable_borrow_reservation_conflict,
     mutable_transmutes,
+    named_asm_labels,
     no_mangle_const_items,
     no_mangle_generic_items,
     non_ascii_idents,
@@ -81,6 +88,8 @@
     soft_unstable,
     stable_features,
     temporary_cstring_as_ptr,
+    text_direction_codepoint_in_comment,
+    text_direction_codepoint_in_literal,
     trivial_bounds,
     trivial_casts,
     trivial_numeric_casts,
@@ -104,6 +113,7 @@
     unsupported_naked_functions,
     unused_allocation,
     unused_assignments,
+    unused_assignments,
     unused_attributes,
     unused_braces,
     unused_comparisons,
@@ -122,7 +132,9 @@
     unused_qualifications,
     unused_unsafe,
     unused_variables,
-    useless_deprecated
+    useless_deprecated,
+    where_clauses_object_safety,
+    while_true
 )]
 #![warn(macro_use_extern_crate, unknown_lints)]
 #![allow(
@@ -330,15 +342,17 @@
 //!     env.insert("ENV_VAR1".to_string(), "MY VALUE".to_string());
 //!     env.insert("ENV_VAR2".to_string(), "MY VALUE2".to_string());
 //!
-//!     let eval_env = |value: String| {
-//!         let mut buffer = String::from("VALUE-");
-//!         buffer.push_str(&value);
-//!         buffer
+//!     let eval_env = |key: String, value: String| {
+//!         let mut updated_key = String::from("KEY-");
+//!         updated_key.push_str(&key);
+//!         let mut updated_value = String::from("VALUE-");
+//!         updated_value.push_str(&value);
+//!         Some((updated_key, updated_value))
 //!     };
 //!
 //!     envmnt::evaluate_and_set_all(&env, eval_env);
 //!
-//!     let value = envmnt::get_or_panic("ENV_VAR1");
+//!     let value = envmnt::get_or_panic("KEY-ENV_VAR1");
 //!     println!("Value Is: {}", &value);
 //! }
 //! ```
@@ -350,10 +364,10 @@
 //!     let mut output = envmnt::load_file("./src/test/var.env");
 //!     assert!(output.is_ok());
 //!
-//!     let eval_env = |value: String| {
-//!         let mut buffer = String::from("PREFIX-");
-//!         buffer.push_str(&value);
-//!         buffer
+//!     let eval_env = |key: String, value: String| {
+//!         let mut updated_value = String::from("PREFIX-");
+//!         updated_value.push_str(&value);
+//!         Some((key, updated_value))
 //!     };
 //!
 //!     output = envmnt::evaluate_and_load_file("./src/test/var.env", eval_env);
@@ -976,7 +990,7 @@ pub fn set_all(env: &IndexMap<String, String>) {
 /// # Arguments
 ///
 /// * `env` - The environment variables to set
-/// * `evaluate` - Evalute function which will modify the read value before it is loaded into the environment
+/// * `evaluate` - Evalute function which will modify the key/value before it is loaded into the environment
 ///
 /// # Example
 ///
@@ -988,23 +1002,25 @@ pub fn set_all(env: &IndexMap<String, String>) {
 ///     env.insert("MY_ENV_VAR".to_string(), "MY VALUE".to_string());
 ///     env.insert("MY_ENV_VAR2".to_string(), "MY VALUE2".to_string());
 ///
-///     let eval_env = |value: String| {
-///         let mut buffer = String::from("VALUE-");
-///         buffer.push_str(&value);
-///         buffer
+///     let eval_env = |key: String, value: String| {
+///         let mut updated_key = String::from("KEY-");
+///         updated_key.push_str(&key);
+///         let mut updated_value = String::from("VALUE-");
+///         updated_value.push_str(&value);
+///         Some((updated_key, updated_value))
 ///     };
 ///
 ///     envmnt::evaluate_and_set_all(&env, eval_env);
 ///
-///     let mut value = envmnt::get_or_panic("MY_ENV_VAR");
+///     let mut value = envmnt::get_or_panic("KEY-MY_ENV_VAR");
 ///     assert_eq!(value, "VALUE-MY VALUE");
-///     value = envmnt::get_or_panic("MY_ENV_VAR2");
+///     value = envmnt::get_or_panic("KEY-MY_ENV_VAR2");
 ///     assert_eq!(value, "VALUE-MY VALUE2");
 /// }
 /// ```
 pub fn evaluate_and_set_all<F>(env: &IndexMap<String, String>, evaluate: F)
 where
-    F: Fn(String) -> String,
+    F: Fn(String, String) -> Option<(String, String)>,
 {
     bulk::evaluate_and_set_all(&env, evaluate)
 }
@@ -1092,16 +1108,16 @@ pub fn load_file(file: &str) -> EnvmntResult<()> {
 /// # Arguments
 ///
 /// * `file` - The file path to load and parse
-/// * `evaluate` - Evalute function which will modify the read value before it is loaded into the environment
+/// * `evaluate` - Evalute function which will modify the key and value before it is loaded into the environment
 ///
 /// # Example
 ///
 /// ```
 /// fn main() {
-///     let eval_env = |value: String| {
-///         let mut buffer = String::from("PREFIX-");
-///         buffer.push_str(&value);
-///         buffer
+///     let eval_env = |key: String, value: String| {
+///         let mut updated_value = String::from("PREFIX-");
+///         updated_value.push_str(&value);
+///         Some((key, updated_value))
 ///     };
 ///
 ///     let output = envmnt::evaluate_and_load_file("./src/test/var.env", eval_env);
@@ -1111,7 +1127,7 @@ pub fn load_file(file: &str) -> EnvmntResult<()> {
 /// ```
 pub fn evaluate_and_load_file<F>(file: &str, evaluate: F) -> EnvmntResult<()>
 where
-    F: Fn(String) -> String,
+    F: Fn(String, String) -> Option<(String, String)>,
 {
     file::evaluate_and_load_file(file, evaluate)
 }
